Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Node ¶
func (*Node) LoadNodeConfig ¶
func (*Node) WaitForEvent ¶
func (node *Node) WaitForEvent(responseChannel chan model.ReactorEvent)
type NodeConfig ¶
type NodeConfig struct {
DefaultValue model.Variable
VariableName string
VariableType string
IsVariableGlobal bool
Props fimpgo.Props
RegisterAsVirtualService bool
VirtualServiceGroup string
VirtualServiceProps map[string]interface{} // mostly used to announce supported features of the service , for instance supported modes , states , setpoints , etc...
ResponseToTopic string // in request-response communication requester can set topic to which server will send response
IsResponseToReq bool // Indicates that the action is response to request and corid field should be set to the same value as request uuid
}
Click to show internal directories.
Click to hide internal directories.